@@ -40,7 +40,7 @@
 from __future__ import annotations
 
 # ## Python StdLib Imports ----
-from typing import Any
+from typing import Any, Optional, Union
 
 # ## Python Third Party Imports ----
 from typeguard import typechecked
@@ -48,7 +48,6 @@ from typeguard import typechecked
 # ## Local First Party Imports ----
 from toolbox_python.bools import strtobool
 from toolbox_python.checkers import is_type
-from toolbox_python.collection_types import str_list
 
 
 # ---------------------------------------------------------------------------- #
@@ -56,7 +55,7 @@ from toolbox_python.collection_types import str_list
 # ---------------------------------------------------------------------------- #
 
 
-__all__: str_list = ["defaults", "Defaults"]
+__all__: list[str] = ["defaults", "Defaults"]
 
 
 # ---------------------------------------------------------------------------- #
@@ -77,14 +76,19 @@ class Defaults:
         When we create and use Python variables, it is sometimes handy to add a default value for that variable.
         This class will handle that process.
 
+    Methods:
+        - get(): From the value that is parsed in to the `value` parameter, convert it to `default` if `value` is `#!py None`, and convert it to `cast` if `cast` is not `#!py None`.
+        - _validate_value_and_default(): Validate to ensure that `value` and `default` are not both `#!py None`.
+        - _validate_type(): Check to ensure that `check_type` is a valid Python type
+
     ???+ example "Examples"
 
-        ```{.py .python linenums="1" title="Set up data for examples"}
+        ```pycon {.py .python linenums="1" title="Set up data for examples"}
         >>> from toolbox_python.defaults import Defaults
         >>> defaults = Defaults()
         ```
 
-        ```{.py .python linenums="1" title="Example 1: Call direct from class"}
+        ```pycon {.py .python linenums="1" title="Example 1: Call direct from class"}
         >>> print(Defaults()(value="this"))
         ```
         <div class="result" markdown>
@@ -94,7 +98,7 @@ class Defaults:
         !!! success "Conclusion: Successfully printed default value direct from class."
         </div>
 
-        ```{.py .python linenums="1" title="Example 2: Call from instantiated class"}
+        ```pycon {.py .python linenums="1" title="Example 2: Call from instantiated class"}
         >>> print(defaults(value="that"))
         ```
         <div class="result" markdown>
@@ -104,7 +108,7 @@ class Defaults:
         !!! success "Conclusion: Successfully printed default value from instantiated class."
         </div>
 
-        ```{.py .python linenums="1" title="Example 3: Cast to `bool`"}
+        ```pycon {.py .python linenums="1" title="Example 3: Cast to `bool`"}
         >>> print(defaults(value="True", cast=bool))
         ```
         <div class="result" markdown>
@@ -114,7 +118,7 @@ class Defaults:
         !!! success "Conclusion: Successfully casted to `#!py bool`."
         </div>
 
-        ```{.py .python linenums="1" title="Example 4: Cast to `int`"}
+        ```pycon {.py .python linenums="1" title="Example 4: Cast to `int`"}
         >>> print(defaults(value="1", cast=int))
         ```
         <div class="result" markdown>
@@ -124,7 +128,7 @@ class Defaults:
         !!! success "Conclusion: Successfully casted to `#!py int`."
         </div>
 
-        ```{.py .python linenums="1" title="Example 5: Cast to `str`"}
+        ```pycon {.py .python linenums="1" title="Example 5: Cast to `str`"}
         >>> print(defaults(value=1, cast=str))
         ```
         <div class="result" markdown>
@@ -134,7 +138,7 @@ class Defaults:
         !!! success "Conclusion: Successfully casted to `#!py str`."
         </div>
 
-        ```{.py .python linenums="1" title="Example 6: Cast to string `'str'`"}
+        ```pycon {.py .python linenums="1" title="Example 6: Cast to string `'str'`"}
         >>> print(defaults(value=1, cast="str"))
         ```
         <div class="result" markdown>
@@ -145,7 +149,7 @@ class Defaults:
         !!! observation "Note: The only difference between this and the previous example is the type of the `cast` parameter. Here, it is a string representation of the type, whereas in the previous example, we parse'ed in the actual `str` class."
         </div>
 
-        ```{.py .python linenums="1" title="Example 7: Invalid cast type"}
+        ```pycon {.py .python linenums="1" title="Example 7: Invalid cast type"}
         >>> print(defaults(value="next", cast="bad_type"))
         ```
         <div class="result" markdown>
@@ -156,7 +160,7 @@ class Defaults:
         !!! failure "Conclusion: Invalid cast type."
         </div>
 
-        ```{.py .python linenums="1" title="Example 8: All blank values"}
+        ```pycon {.py .python linenums="1" title="Example 8: All blank values"}
         >>> print(defaults(value=None, cast=None))
         ```
         <div class="result" markdown>
@@ -197,14 +201,14 @@ class Defaults:
     def get(
         self,
         value: Any,
-        default: Any | None = None,
-        cast: str | type | None = None,
+        default: Optional[Any] = None,
+        cast: Optional[Union[str, type]] = None,
     ) -> Any:
         """
         !!! note "Summary"
             From the value that is parsed in to the `value` parameter, convert it to `default` if `value` is `#!py None`, and convert it to `cast` if `cast` is not `#!py None`.
 
-        ???+ info "Details"
+        ???+ abstract "Details"
             The detailed steps will be:
 
             1. Validate the input (using the internal [`._validate_value_and_default()`][toolbox_python.defaults.Defaults._validate_value_and_default] & [`._validate_type()`][toolbox_python.defaults.Defaults._validate_type] methods),
@@ -225,23 +229,112 @@ class Defaults:
                 Must be one of: `#!py ["bool", "dict", "int", "float", "list", "str", "tuple"]`.<br>
                 Defaults to `#!py None`.
 
+        Raises:
+            (TypeCheckError):
+                If any of the inputs parsed to the parameters of this function are not the correct type. Uses the [`@typeguard.typechecked`](https://typeguard.readthedocs.io/en/stable/api.html#typeguard.typechecked) decorator.
+
         Returns:
             value (Any):
                 The updated/defaulted/casted value.
 
+        ???+ example "Examples"
+            ```pycon {.py .python linenums="1" title="Prepare data for examples"}
+            >>> from toolbox_python.defaults import Defaults
+            >>> defaults = Defaults()
+            ```
+
+            ```pycon {.py .python linenums="1" title="Example 1: Call direct from class"}
+            >>> print(Defaults()(value="this"))
+            ```
+            <div class="result" markdown>
+            ```{.txt .text title="Terminal"}
+            "this"
+            ```
+            !!! success "Conclusion: Successfully printed default value direct from class."
+            </div>
+
+            ```pycon {.py .python linenums="1" title="Example 2: Call from instantiated class"}
+            >>> print(defaults(value="that"))
+            ```
+            <div class="result" markdown>
+            ```{.txt .text title="Terminal"}
+            "that"
+            ```
+            !!! success "Conclusion: Successfully printed default value from instantiated class."
+            </div>
+
+            ```pycon {.py .python linenums="1" title="Example 3: Cast to `bool`"}
+            >>> print(defaults(value="True", cast=bool))
+            ```
+            <div class="result" markdown>
+            ```{.txt .text title="Terminal"}
+            True
+            ```
+            !!! success "Conclusion: Successfully casted to `#!py bool`."
+            </div>
+
+            ```pycon {.py .python linenums="1" title="Example 4: Cast to `int`"}
+            >>> print(defaults(value="1", cast=int))
+            ```
+            <div class="result" markdown>
+            ```{.txt .text title="Terminal"}
+            1
+            ```
+            !!! success "Conclusion: Successfully casted to `#!py int`."
+            </div>
+
+            ```pycon {.py .python linenums="1" title="Example 5: Cast to `str`"}
+            >>> print(defaults(value=1, cast=str))
+            ```
+            <div class="result" markdown>
+            ```{.txt .text title="Terminal"}
+            "1"
+            ```
+            !!! success "Conclusion: Successfully casted to `#!py str`."
+            </div>
+
+            ```pycon {.py .python linenums="1" title="Example 6: Cast to string `'str'`"}
+            >>> print(defaults(value=1, cast="str"))
+            ```
+            <div class="result" markdown>
+            ```{.txt .text title="Terminal"}
+            "1"
+            ```
+            !!! success "Conclusion: Successfully casted to `#!py str`."
+            !!! observation "Note: The only difference between this and the previous example is the type of the `cast` parameter. Here, it is a string representation of the type, whereas in the previous example, we parse'ed in the actual `str` class."
+            </div>
+
+            ```pycon {.py .python linenums="1" title="Example 7: Invalid cast type"}
+            >>> print(defaults(value="next", cast="bad_type"))
+            ```
+            <div class="result" markdown>
+            ```{.txt .text title="Terminal"}
+            AttributeError: The value for `type` is invalid: `bad_type`.
+            Must be a valid type: ['bool', 'dict', 'int', 'float', 'list', 'str', 'tuple']
+            ```
+            !!! failure "Conclusion: Invalid cast type."
+            </div>
+
+            ```pycon {.py .python linenums="1" title="Example 8: All blank values"}
+            >>> print(defaults(value=None, cast=None))
+            ```
+            <div class="result" markdown>
+            ```{.txt .text title="Terminal"}
+            AttributeError: Both `value` and `default` are blank: 'None', 'None'.
+            If `value` is blank, then `default` cannot be blank.
+            ```
+            !!! failure "Conclusion: Both `value` and `default` are blank."
+            </div>
+
         ??? tip "See Also"
             - [`Defaults._validate_value_and_default()`][toolbox_python.defaults.Defaults._validate_value_and_default]
             - [`Defaults._validate_type()`][toolbox_python.defaults.Defaults._validate_type]
         """
-        (
-            self._validate_value_and_default(
-                value=value, default=default
-            )._validate_type(check_type=cast)
-        )
+        self._validate_value_and_default(value=value, default=default)._validate_type(check_type=cast)
         if value is None:
             value = default
         if cast is not None:
-            if (cast is bool or cast == "bool") and is_type(value, str):
+            if (cast is bool or cast == "bool") and isinstance(value, str):
                 value = bool(strtobool(value))
             elif isinstance(cast, str):
                 value = eval(cast)(value)
@@ -251,8 +344,8 @@ class Defaults:
 
     def _validate_value_and_default(
         self,
-        value: Any | None = None,
-        default: Any | None = None,
+        value: Optional[Any] = None,
+        default: Optional[Any] = None,
     ) -> Defaults:
         """
         !!! note "Summary"
@@ -267,7 +360,7 @@ class Defaults:
                 Defaults to `#!py None`.
 
         Raises:
-            AttributeError: If both `value` and `default` are `#!py None`.
+            (AttributeError): If both `value` and `default` are `#!py None`.
 
         Returns:
             self (Defaults):
@@ -285,7 +378,7 @@ class Defaults:
 
     def _validate_type(
         self,
-        check_type: str | type | None = None,
+        check_type: Optional[Union[str, type]] = None,
     ) -> Defaults:
         """
         !!! note "Summary"
@@ -298,7 +391,7 @@ class Defaults:
                 Defaults to `#!py None`.
 
         Raises:
-            AttributeError: If `check_type` is _both_ not `#!py None` _and_ if it is not one of the valid Python types.
+            (AttributeError): If `check_type` is _both_ not `#!py None` _and_ if it is not one of the valid Python types.
 
         Returns:
             self (Defaults):
@@ -307,7 +400,7 @@ class Defaults:
         ??? tip "See Also"
             - [`Defaults.get()`][toolbox_python.defaults.Defaults.get]
         """
-        valid_types: str_list = [
+        valid_types: list[str] = [
             "bool",
             "dict",
             "int",
@@ -316,6 +409,7 @@ class Defaults:
             "str",
             "tuple",
         ]
+        retype: str | type | None = None
         if check_type is None:
             return self
         elif is_type(check_type, str):
@@ -324,8 +418,7 @@ class Defaults:
             retype = check_type.__name__  # type: ignore
         if retype is not None and retype not in valid_types:
             raise AttributeError(
-                f"The value for `type` is invalid: `{retype}`.\n"
-                f"Must be a valid type: {valid_types}."
+                f"The value for `type` is invalid: `{retype}`.\n" f"Must be a valid type: {valid_types}."
             )
         return self
 
