@@ -39,28 +39,21 @@
 
 
 # ## Python StdLib Imports ----
+from collections.abc import Collection
 from itertools import product as itertools_product
-from typing import Any, Optional, Union
+from typing import Any, Optional
 
 # ## Python Third Party Imports ----
 from more_itertools import collapse as itertools_collapse
 from typeguard import typechecked
 
-# ## Local First Party Imports ----
-from toolbox_python.collection_types import (
-    any_list,
-    any_tuple,
-    collection,
-    scalar,
-    str_list,
-)
-
 
 # ---------------------------------------------------------------------------- #
 #  Exports                                                                  ####
 # ---------------------------------------------------------------------------- #
 
-__all__: str_list = ["flatten", "flat_list", "product"]
+
+__all__: list[str] = ["flatten", "flat_list", "product"]
 
 
 # ---------------------------------------------------------------------------- #
@@ -72,22 +65,22 @@ __all__: str_list = ["flatten", "flat_list", "product"]
 
 @typechecked
 def flatten(
-    list_of_lists: Union[scalar, collection],
+    list_of_lists: Collection[Collection[Any]],
     base_type: Optional[type] = None,
     levels: Optional[int] = None,
-) -> any_list:
+) -> list[Any]:
     """
     !!! note "Summary"
         For a given `#!py list` of `#!py list`'s, flatten it out to be a single `#!py list`.
 
-    ???+ info "Details"
+    ???+ abstract "Details"
         Under the hood, this function will call the [`#!py more_itertools.collapse()`][more_itertools.collapse] function. The difference between this function and the [`#!py more_itertools.collapse()`][more_itertools.collapse] function is that the one from [`#!py more_itertools`][more_itertools] will return a `chain` object, not a `list` object. So, all we do here is call the [`#!py more_itertools.collapse()`][more_itertools.collapse] function, then parse the result in to a `#!py list()` function to ensure that the result is always a `#!py list` object.
 
         [more_itertools]: https://more-itertools.readthedocs.io/en/stable/api.html
         [more_itertools.collapse]: https://more-itertools.readthedocs.io/en/stable/api.html#more_itertools.collapse
 
     Params:
-        list_of_lists (list[any_list]):
+        list_of_lists (Collection[Collection[Any]]):
             The input `#!py list` of `#!py list`'s that you'd like to flatten to a single-level `#!py list`.
         base_type (Optional[type], optional):
             Binary and text strings are not considered iterable and will not be collapsed. To avoid collapsing other types, specify `base_type`.<br>
@@ -97,7 +90,7 @@ def flatten(
             Defaults to `#!py None`.
 
     Raises:
-        TypeCheckError:
+        (TypeCheckError):
             If any of the inputs parsed to the parameters of this function are not the correct type. Uses the [`@typeguard.typechecked`](https://typeguard.readthedocs.io/en/stable/api.html#typeguard.typechecked) decorator.
 
     Returns:
@@ -196,7 +189,7 @@ def flatten(
     """
     return list(
         itertools_collapse(
-            iterable=list_of_lists,  # type: ignore
+            iterable=list_of_lists,
             base_type=base_type,
             levels=levels,
         )
@@ -204,7 +197,7 @@ def flatten(
 
 
 @typechecked
-def flat_list(*inputs: Any) -> any_list:
+def flat_list(*inputs: Any) -> list[Any]:
     """
     !!! note "Summary"
         Take in any number of inputs, and output them all in to a single flat `#!py list`.
@@ -214,11 +207,11 @@ def flat_list(*inputs: Any) -> any_list:
             Any input.
 
     Raises:
-        TypeCheckError:
+        (TypeCheckError):
             If any of the inputs parsed to the parameters of this function are not the correct type. Uses the [`@typeguard.typechecked`](https://typeguard.readthedocs.io/en/stable/api.html#typeguard.typechecked) decorator.
 
     Returns:
-        (any_list):
+        (list[Any]):
             The input having been coerced to a single flat `#!py list`.
 
     ???+ example "Examples"
@@ -313,12 +306,12 @@ def flat_list(*inputs: Any) -> any_list:
     return flatten(list(inputs))
 
 
-def product(*iterables) -> list[any_tuple]:
+def product(*iterables: Any) -> list[tuple[Any, ...]]:
     """
     !!! note "Summary"
         For a given number of `#!py iterables`, perform a cartesian product on them, and return the result as a list.
 
-    ???+ info "Details"
+    ???+ abstract "Details"
         Under the hood, this function will call the [`#!py itertools.product()`][itertools.product] function. The difference between this function and the [`#!py itertools.product()`][itertools.product] function is that the one from [`#!py itertools`][itertools] will return a `product` object, not a `list` object. So, all we do here is call the [`#!py itertools.product()`][itertools.product] function, then parse the result in to a `#!py list()` function to ensure that the result is always a `#!py list` object.
 
         [itertools]: https://docs.python.org/3/library/itertools.html
